@@ -7,11 +7,11 @@ CGI::Application::Plugin::AnyTemplate - Use any templating system from within CG
 
 =head1 VERSION
 
-Version 0.10_05
+Version 0.01
 
 =cut
 
-our $VERSION = '0.10_05';
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -51,8 +51,7 @@ C<CGI::Application::Plugin::AnyTemplate> allows you to use any
 supported Perl templating system using a single consistent interface.
 
 Currently supported templating systems include L<HTML::Template>,
-L<HTML::Template::Expr>, L<HTML::Template::Pluggable>,
-L<Template::Toolkit|Template> and L<Petal>.
+L<HTML::Template::Expr>, L<Template::Toolkit> and L<Petal>.
 
 You can access any of these templating systems using the same interface.
 In this way, you can use the same code and switch templating systems on
@@ -61,17 +60,17 @@ the fly.
 This approach has many uses.  For instance, it can be useful in
 migrating your application from one templating system to another.
 
-=head2 Embedded Components
+=head2 Component Dispatch
 
 In addition to template abstraction, C<AnyTemplate> also provides a
-I<embedded component mechanism>.  For instance, you might include a
+I<component dispatch mechanism>.  For instance, you might include a
 I<header> component at the top of every page and a I<footer> component
 at the bottom of every page.
 
 These components are actually full L<CGI::Application> run modes, and
 can do anything normal run mode can do, including processing form
 parameters and filling in their own templates.  See
-below under L<"EMBEDDED COMPONENTS"> for details.
+below under L<COMPONENT DISPATCH> for details.
 
 =head2 Multiple Named Template Configurations
 
@@ -149,32 +148,22 @@ or (with slightly less typing):
     $template->param('foo' => 'bar');
     $template->output;
 
-See also below under L<"CHANGING THE NAME OF THE 'template' METHOD">.
+See also below under L<CHANGING THE NAME OF THE 'template' METHOD>.
 
 =cut
 
 use strict;
+use base 'Exporter';
 use CGI::Application;
 use Carp;
-use Clone;
 use Scalar::Util qw(weaken);
 
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $CAPAT_Namespace);
+use Clone;
 
-@ISA = ('Exporter');
+our @ISA    = 'Exporter';
+our @EXPORT = qw(template);
 
-@ISA         = 'Exporter';
-@EXPORT      = qw(template);
-@EXPORT_OK   = qw(load_tmpl);
-%EXPORT_TAGS = (load_tmpl => ['load_tmpl', @EXPORT]);
-
-$CAPAT_Namespace = '__ANY_TEMPLATE';
-
-if (CGI::Application->can('new_hook')) {
-    CGI::Application->new_hook('template_pre_process');
-    CGI::Application->new_hook('template_post_process');
-    CGI::Application->new_hook('load_tmpl');
-}
+our $CAPAT_Namespace = '__ANY_TEMPLATE';
 
 sub _new {
     my $proto     = shift;
@@ -290,7 +279,7 @@ then the actual filename will depend on the current template driver:
     Petal                  myfile.xhtml
 
 The per-type extension is controlled by the driver config for each
-C<AnyTemplate> driver (see below under L<"Driver and Native Configuration"> for how
+C<AnyTemplate> driver (see below under L<Driver Configuration> for how
 to set this).
 
 The C<auto_add_template_extension> feature is on by default.  To disable
@@ -300,40 +289,15 @@ it, pass a value of zero:
         auto_add_template_extension => 0,
     );
 
-The automatic extension feature is not just there to save typing - it's
-actually there so you can have templates of different types sitting in
-the same directory.
+=item dispatcher_class
 
-    sub my_runmode {
-        my $self = shift;
-        $self->template->fill;
-    }
-
-Then in your template path you can have three files:
-
-    my_runmode.html
-    my_runmode.tmpl
-    my_runmode.xhtml
-
-Then you can change which templates is used by changing the value of
-C<type> that you pass to C<< $self->template->config >>.
-
-For applications that want to dynamically choose their template system
-without changing app code, it's a cleaner solution to use the extensions
-than trying to swap template paths at runtime.  Even if you keep each
-type of template in its own directory, it's simpler to include all
-the directories all the time and use different extensions for different
-template types.
-
-=item component_handler_class
-
-Normally, component embedding is handled by
-L<CGI::Application::Plugin::AnyTemplate::ComponentHandler>.  If you want to
+Normally, component dispatching is handled by
+L<CGI::Application::Plugin::AnyTemplate::Dispatcher>.  If you want to
 use a different class for this purpose, specify the class name as the
 value of this paramter.
 
 It still has to provide the same interface as
-L<CGI::Application::Plugin::AnyTemplate::ComponentHandler>.  See the source
+L<CGI::Application::Plugin::AnyTemplate::Dispatcher>.  See the source
 code of that module for details.
 
 =back
@@ -357,12 +321,6 @@ C<config>, by including subsections for each driver type:
             die_on_bad_params  => 0,
             template_extension => '.html',
         },
-        HTMLTemplatePluggable => {
-            cache              => 1,
-            global_vars        => 1,
-            die_on_bad_params  => 0,
-            template_extension => '.html',
-        },
         TemplateToolkit => {
             POST_CHOMP         => 1,
             template_extension => '.tmpl',
@@ -389,30 +347,19 @@ C<Template::Toolkit> configuration parameter.
 For details on driver configuration, see the docs for the individual
 drivers:
 
-=over 4
-
-=item L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate>
-
-=item L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr>
-
-=item L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplatePluggable>
-
-=item L<CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit>
-
-=item L<CGI::Application::Plugin::AnyTemplate::Driver::Petal>
-
-=back
+    CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
+    CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
+    CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
+    CGI::Application::Plugin::AnyTemplate::Driver::Petal
 
 =head3 Copying Query data into Templates
 
-B<This feature is now deprecated and will be removed in a future release.>
+By default, all data in C<< $self->query >> are copied into the template
+object before the template is processed.
 
-When you enable this feature all data in C<< $self->query >> are copied
-into the template object before the template is processed.
-
-For the C<HTMLTemplate>, C<HTMLTemplateExpr> and
-C<HTMLTemplatePluggable> drivers this is done with the C<associate>
-feature of L<HTML::Template> and L<HTML::Template::Expr>, respectively:
+For the C<HTMLTemplate> and C<HTMLTemplateExpr> drivers this is done
+with the C<associate> feature of L<HTML::Template> and
+L<HTML::Template::Expr>, respectively:
 
     my $template = HTML::Template->new(
         associate => $self->query,
@@ -421,60 +368,25 @@ feature of L<HTML::Template> and L<HTML::Template::Expr>, respectively:
 For the other systems, this feature is emulated, by copying the query
 params into the template params before the template is processed.
 
-To enable this feature, pass a true value to C<associate_query> or
+To disable this feature, pass a false value to C<associate_query> or
 C<emulate_associate_query> (depending on the template system):
+
     $self->template->config(
         default_type => 'HTMLTemplate',
         HTMLTemplate => {
-            associate_query => 1,
+            associate_query => 0,
         },
         HTMLTemplateExpr => {
-            associate_query => 1,
-        },
-        HTMLTemplatePluggable => {
-            associate_query => 1,
+            associate_query => 0,
         },
         TemplateToolkit => {
-            emulate_associate_query => 1,
+            emulate_associate_query => 0,
         },
         Petal => {
-            emulate_associate_query => 1,
+            emulate_associate_query => 0,
         },
     );
 
-The reason this feature is now disabled by default is that it
-poses a potential XSS (Cross Site Scripting) security risk.
-
-The reason this feature is now deprecated is that in an ideal world
-developers shouldn't have to flatten objects and hashes in order to make
-them available to their templates. They should be able to pass the query
-object (or another object such as a config object) directly into the
-template:
-
-    $template->param(
-        'query' => $self->query,
-        'cfg'   => $self->cfg,
-        'ENV'   => $ENV,
-    );
-
-And in the template retrieve parameters directly:
-
-    your username: [% query.param('username') %]
-    administrator: [% cfg.admin %]
-    hostname:      [% ENV.SERVER_NAME %]
-
-This approach works with L<Template::Toolkit|Template>, L<Petal>, and
-L<HTML::Template::Pluggable> (via the L<HTML::Template::Plugin::Dot> plugin).
-
-Note that C<associate> and C<associate_query> are not compatible.  So if
-you want to associate the query and an additional object, pass a list to
-C<associate>:
-
-    $template->config(
-        HTMLTemplate => {
-            associate => [$self->query, $self->conf]
-        }
-    );
 
 
 =cut
@@ -482,7 +394,7 @@ C<associate>:
 sub config {
     my $self = shift;
 
-    my $config = ref $_[0] eq 'HASH' ? { %{ $_[0] } } : { @_ };
+    my $config = ref $_[0] eq 'HASH' ? $_[0] : { @_ };
 
     $config->{'callers_package'} = scalar caller;
 
@@ -525,40 +437,11 @@ This can be as simple (and magical) as:
 
 When you call C<load> with no parameters, it uses the default template
 type, the default template configuration, and it determines the name of
-the template based on the name of the current run mode.  It determines
-the current run mode by calling C<< $self->get_current_runmode >>.
+the template based on the name of the current run mode.
 
-If you want to have the current runmode updated when you pass control to
-another runmode, use the L<CGI::Application::Plugin::Forward> module:
-
-    use CGI::Application::Plugin::Forward;
-
-    sub first_runmode {
-        my $self = shift;
-        return $self->forward('second_runmode');
-    }
-    sub second_runmode {
-        my $self = shift;
-        my $template = $self->template->load;  # loads 'second_runmode.html'
-    }
-
-If instead you call C<< $self->other_method >> directly, the value
-of C<< $self->get_current_runmode >> will not be updated:
-
-    sub first_runmode {
-        my $self = shift;
-        return $self->other_method;
-    }
-    sub other_method {
-        my $self = shift;
-        my $template = $self->template->load;  # loads 'first_runmode.html'
-    }
-
-If you call C<load> with one paramter, it is taken to be either the
-filename or a reference to a string containing the template text:
+If you call C<load> with one paramter, it is taken to be the filename.
 
     my $template = $self->template->load('somefile');
-    my $template = $self->template->load(\$some_text);
 
 If the parameter C<auto_add_template_exension> is true, then the
 appropriate extension will be added for this template type.
@@ -576,14 +459,8 @@ you can specify filename and configuration paramters directly:
         },
     );
 
-To initialize the template from a string rather than a file, use:
-
-    my $template = $self->template->load(
-        string =>  \$some_text,
-    );
-
-The configuration parameters you pass to C<load> are merged with the
-configuration that was passed to L<"config">.
+The configuration is merged with the configuration that was passed to
+L<config>.
 
 You can include any of the configuration parameters that you can pass to
 config, plus the following extra parameters:
@@ -592,24 +469,7 @@ config, plus the following extra parameters:
 
 =item file
 
-If you are loading the template from a file, then the C<file> parameter
-contains the template's filename.
-
-=item string
-
-If you are loading the template from a string, then the C<string> parameter
-contains the text of the template.  It can be either a scalar or a
-reference to a scalar.  Both of the following will work:
-
-    # passing a string
-    my $template = $self->template->load(
-        string => $some_text,
-    );
-
-    # passing a reference to a string
-    my $template = $self->template->load(
-        string => \$some_text,
-    );
+The template's filename.
 
 =item add_include_paths
 
@@ -634,17 +494,10 @@ sub load {
                 $config = $_[0];
             }
             else {
-                # args: single value (=filename or string_ref)
-                if (ref $_[0] eq 'SCALAR') {
-                    $config = {
-                        'string' => $_[0],
-                    };
-                }
-                else {
-                    $config = {
-                        'file' => $_[0],
-                    };
-                }
+                # args: single value (=filename)
+                $config = {
+                     'file' => $_[0],
+                };
             }
         }
         else {
@@ -653,8 +506,14 @@ sub load {
         }
     }
 
+    # Where we get our subroutine name from.  Usually from the subroutine
+    # immediately above us, but occasionally from further up
+    # (such as when we are called from fill or process)
+    my $call_level = delete $config->{'call_level'} || 1;
+
     # set current configuration from base
 
+
     if (keys %$config) {
         $self->{'current_config'} = Clone::clone($self->{'base_config'});
         $self->_add_configuration($self->{'current_config'}, $config);
@@ -665,6 +524,9 @@ sub load {
 
     my $plugin_config = $self->{'current_config'}{'plugin_config'};
 
+    # manage include paths
+
+    my $include_paths = $self->_merged_include_paths($plugin_config);
 
     # determine template type
 
@@ -696,58 +558,21 @@ sub load {
         }
     }
 
-    # Get the string, if supplied
-    my $string_ref;
-    if (exists $plugin_config->{'string'}) {
-        $string_ref = $plugin_config->{'string'} || '';
-        $string_ref = \$string_ref unless ref $string_ref;
-    }
-
-    # if no string, then guess template filename
-    my $filename;
-    unless ($string_ref) {
-        $filename = $self->_guess_template_filename($plugin_config, \%driver_config, $type, $self->{'webapp'}->get_current_runmode);
-    }
-
-
-    # call load_tmpl hook
-    my %tmpl_params;
-    if ($self->{'webapp'}->can('call_hook')) {
-        my %ht_params = (
-           'path' => $plugin_config->{'add_include_paths'},
-        );
-        $self->{'webapp'}->call_hook(
-            'load_tmpl',
-            \%ht_params,
-            \%tmpl_params,
-            $filename,
-        );
-        $plugin_config->{'add_include_paths'} = $ht_params{'path'};
-    }
-
-
-    # manage include paths
-
-    my $include_paths = $self->_merged_include_paths($plugin_config);
+    # guess template filename
+    my $filename = $self->_guess_template_filename($plugin_config, \%driver_config, $type, (caller($call_level))[3]);
 
     # create and initialize driver
 
     my $driver = $driver_class->_new(
-         'driver_config'           => \%driver_config,
-         'native_config'           => $native_config,
-         'include_paths'           => $include_paths,
-         'filename'                => $filename,
-         'string_ref'              => $string_ref,
-         'callers_package'         => $plugin_config->{'callers_package'},
-         'webapp'                  => $self->{'webapp'},
-         'component_handler_class' => $plugin_config->{'component_handler_class'},
+         'driver_config'    => \%driver_config,
+         'native_config'    => $native_config,
+         'include_paths'    => $include_paths,
+         'filename'         => $filename,
+         'callers_package'  => $plugin_config->{'callers_package'},
+         'webapp'           => $self->{'webapp'},
+         'dispatcher_class' => $plugin_config->{'dispatcher_class'},
     );
 
-    # Store the tmpl params we picked up from the load_tmpl hook
-    if (keys %tmpl_params) {
-        $driver->param(%tmpl_params);
-    }
-
     return $driver;
 
 }
@@ -762,8 +587,7 @@ sub _plugin_config_keys {
         include_paths
         add_include_paths
         file
-        string
-        component_handler_class
+        dispatcher_class
     /;
 }
 
@@ -853,21 +677,11 @@ sub _add_configuration {
 sub _merged_include_paths {
     my ($self, $config) = @_;
 
-    my @include_paths;
-
-    if (my $tmpl_path = $self->{'webapp'}->tmpl_path) {
-        if (ref $tmpl_path ne 'ARRAY') {
-            $tmpl_path = [ $tmpl_path ];
-        }
-        push @include_paths, @$tmpl_path;
-    }
-
     if ($config->{'include_paths'} and ref $config->{'include_paths'} ne 'ARRAY') {
         $config->{'include_paths'} = [ $config->{'include_paths'} ];
     }
-    push @include_paths, @{ $config->{'include_paths'} || [] };
-
 
+    my @include_paths     = @{ $config->{'include_paths'} || [] };
 
     $config->{'add_include_paths'} ||= [];
     $config->{'add_include_paths'} = [$config->{'add_include_paths'}] unless ref $config->{'add_include_paths'} eq 'ARRAY';
@@ -915,15 +729,17 @@ sub _require_driver {
 }
 
 sub _guess_template_filename {
-    my ($self, $plugin_config, $driver_config, $type, $crm) = @_;
+    my ($self, $plugin_config, $driver_config, $type, $calling_sub) = @_;
 
     my $filename;
     if (exists $plugin_config->{'file'}) {
         $filename = $plugin_config->{'file'};
     }
     else {
-        # filename set to current run mode
-        $filename = $crm;
+        # split off subroutine name from package name
+        $filename = substr(
+            $calling_sub, rindex($calling_sub, '::') + 2
+        );
     }
 
     if ($plugin_config->{'auto_add_template_extension'}) {
@@ -943,7 +759,7 @@ sub _guess_template_filename {
 Fill is a convenience method which in a single step creates the
 template, fills it with the template paramters and returns its output.
 
-You can call it with or without a filename (or string ref).
+You can call it with or without a filename.
 
 The code:
 
@@ -954,16 +770,6 @@ is equivalent to:
     my $template = $self->template->load('filename');
     $template->output(\%params);
 
-
-And the code:
-
-    $self->template->fill(\$some_text, \%params);
-
-is equivalent to:
-
-    my $template = $self->template->load(\$some_text);
-    $template->output(\%params);
-
 And the code:
 
     $self->template->fill(\%params);
@@ -979,15 +785,17 @@ is equivalent to:
 sub fill {
     my $self = shift;
 
-    my ($file_or_string, $params, $template);
+    my ($file, $params, $template);
 
     if (@_ == 2) {
-        ($file_or_string, $params) = @_;
-        $template = $self->load($file_or_string);
+        ($file, $params) = @_;
+        $template = $self->load($file);
     }
     else {
         ($params) = @_;
-        $template = $self->load;
+        $template = $self->load(
+            call_level => 2,
+        );
     }
 
     $params ||= {};
@@ -997,7 +805,7 @@ sub fill {
 
 =head2 process
 
-C<"process"> is an alias for L<"fill">.
+C<process> is an alias for L<fill>.
 
 =cut
 
@@ -1005,137 +813,14 @@ sub process {
     goto &fill;
 }
 
-=head1 APPLICATION METHODS
-
-These methods are called directly on your application's C<$self> object.
-
-=head2 load_tmpl
-
-This is an emulation of L<CGI::Application>'s built-in C<load_tmpl>
-method.  For instance:
-
-    $self->load_tmpl('some_template.html');
-
-It is not exported by default.  To enable it, use:
-
-    use CGI::Application::Plugin::AnyTemplate qw/:load_tmpl/;
-
-You can call it the same way as documented in C<CGI::Application> and it
-will have the same effect.  However, it will respect the current
-template C<type>, so you can still use it to fill templates of different
-backends.
-
-The idea is that you can take an existing L<CGI::Application>-based
-webapp which uses C<HTML::Template> templates, and add the following
-code to it:
-
-    use CGI::Application::Plugin::AnyTemplate qw/:load_tmpl/;
-
-    sub setup {
-        my $self = shift;
-        $self->template->config(type => TemplateToolkit);
-    }
-
-This will change all existing calls to load_tmpl within your application
-to use L<Template::Toolkit|Template> based templates.
-
-Calling:
-
-    my $template = $self->load_tmpl('some_template.html');
-
-It is the equivalent of calling:
-
-    my $template = $self->template->load(
-        file => 'some_template.html',
-        auto_add_template_extension => 0,
-    );
-
-If you add extra options to C<load_tmpl>, these will be assumed to be
-L<HTML::Template> specific options, with the exception of the C<path>
-option, which will be extracted and used as 'add_include_path':
-
-    my $template = $self->load_tmpl('some_template.html',
-        cache => 0,
-        path  => '/path/to/templates',
-    );
-
-This will get translated into:
-
-    my $template = $self->template->load(
-        file => 'some_template.html',
-        auto_add_template_extension => 0,
-        add_include_path => '/path/to/templates',
-        HTMLTemplate => {
-            cache => 0,
-        }
-    );
-
-Note that if you specify any L<HTML::Template>-specific options here,
-they will completely overwrite any options that you passed to config.
-
-Some notes and caveats about using the C<load_tmpl> method:
-
-=over 4
-
-=item *
-
-This method only works for the default template configuration (i.e. C<< $self->template() >>).
-If you set up a named configuration (e.g. C<< $self->template('myconfig') >>)
-there is no way to access it with C<load_tmpl>.  Since plugins should be
-using named configurations, this means that the C<load_tmpl> method
-should not be used by plugins.  See L<"NOTES FOR AUTHORS OF PLUGINS AND REUSABLE APPLICATIONS">,
-below.
-
-=item *
-
-The C<load_tmpl> method does not automatically add an extension to the
-filename you pass to it, even if you have C<auto_add_template_extension>
-set to a true value in your call to C<< $self->template->config >>.
-
-=back
-
-=cut
-
-sub load_tmpl {
-    my ($self, $filename, %ht_options) = @_;
-
-    my %params = (
-        file         => $filename,
-        auto_add_template_extension => 0,
-        HTMLTemplate => \%ht_options,
-    );
-
-    my $path = delete $ht_options{'path'};
-
-    if ($path) {
-        $params{'add_include_paths'} = $path;
-    }
-
-    return $self->template->load(%params);
-}
-
-=head2 tmpl_path
-
-You can set the template C<include_paths> by calling
-C<< $self->tmpl_path('/path/to/templates') >>.
-
-You can also do so by passing a value to the C<TMPL_PATH> parameter to
-your application's C<new> method:
-
-    my $webapp = App->new(
-        TMPL_PATH => '/path/to/templates',
-    );
-
-Paths that you set via C<tmpl_path>/C<TMPL_PATH> will be put B<last> in
-the list of include paths, after C<add_include_paths> and
-C<include_paths>.
-
 =head1 DRIVER METHODS
 
 These are the most commonly used methods of the C<AnyTemplate> driver
 object.  The driver is what you get back from calling C<< $self->template->load >>.
 
-=head2 param
+=over 4
+
+=item param
 
 The C<param> method gets and sets values within the template.
 
@@ -1154,7 +839,7 @@ The C<param> method gets and sets values within the template.
 It is designed to behave similarly to the C<param> method in other modules like
 L<CGI> and L<HTML::Template>.
 
-=head2 get_param_hash
+=item get_param_hash
 
 Returns the template variables as a hash of names and values.
 
@@ -1167,7 +852,7 @@ internally to contain the values:
 
     $params_ref->{'foo'} = 'bar';  # directly change parameter 'foo'
 
-=head2 output
+=item output
 
 Returns the template with all the values filled in.
 
@@ -1178,85 +863,18 @@ You can also supply names and values to the template at this stage:
     return $template->output('name' => 'value', 'name2' => 'value2');
 
 
-When you call the C<output> method, any components embedded in the
-template are run.  See L<"EMBEDDED COMPONENTS">, below.
+=back
+
 
 =head1 PRE- AND POST- PROCESS
 
-There are several ways to customize the template process.  You can
-modify the template parameters before the template is filled, and you
-can modify the output of the template after it has been filled.
+Before the template output is generated, your application's
+C<< $self->template_pre_process >> method is called.
+This method is passed a reference to the C<$template> object.
 
-Multiple applications and plugins can hook into the template process
-pipeline, each making changes to the template input and output.
+It can modify the parameters passed into the template by using the C<param> method:
 
-For instance, it will be possible to make a general-purpose
-C<CGI::Application> plugin that adds arbitrary data to each new
-template (such as query parameters or configuration data).
-
-Note that the API has changed for version 0.10 in a
-non-backwards-compatible way in order to use the new hook system
-provided by recent versions of C<CGI::Application>.
-
-=head2 The load_tmpl hook
-
-The C<load_tmpl> hook is designed to be compatible with the C<load_tmpl>
-hook defined by C<CGI::Application> itself.
-
-The C<load_tmpl> hook is called before the template object is created.
-Any callbacks that you register to this hook will be called before each
-template is loaded.  Register a C<load_tmpl> callback with:
-
-   $self->add_callback('load_tmpl',\&my_load_tmpl);
-
-When the C<load_tmpl> callback is executed it will be passed three
-arguments (I<adapted from the> L<CGI::Application> I<docs>):
-
- 1. A hash reference of the extra params passed into C<load_tmpl>
-    (ignored by AnyTemplate with the exception of 'path')
-
- 2. Followed by a hash reference to template parameters.
-    You can modify this hash by reference to affect values that are
-    actually passed to the param() method of the template object.
-
- 3. The name of the template file.
-
-Here's an example stub for a load_tmpl() callback:
-
-    sub my_load_tmpl_callback {
-        my ($self, $ht_params, $tmpl_params, $tmpl_file) = @_;
-        # modify $tmpl_params by reference...
-    }
-
-Currently, of all the params in C<$ht_params>, all but 'path' are
-ignored, because these are specific to C<HTML::Template>.  If you want to
-write a generic callback that needs to be able to access or modify
-C<HTML::Template> parameters then let me know, or add a feature request
-on L<http://rt.cpan.org>.
-
-The C<path> param of C<$ht_params> is initially set to the value of
-C<add_include_path> (if set).  Your callback can modify the C<path>
-param, and C<add_include_param> will be set to the result.
-
-Plugin authors who want to provide template processing features are
-encouraged to use the 'load_tmpl' hook when possible, since it will work
-both with AnyTemplate and with L<CGI::Application>'s built-in
-C<load_tmpl>.
-
-=head2 The template_pre_process and template_post_process hooks
-
-Before the template output is generated, the C<< template_pre_process >>
-hook is called.  Any callbacks that you register to this hook will be
-called before each template is processed.  Register a
-C<template_pre_process> callback as follows:
-
-    $self->add_callback('template_pre_process', \&my_tmpl_pre_process);
-
-Pre-process callbacks will be passed a reference to the C<$template>
-object, and can can modify the parameters passed into the template by
-using the C<param> method:
-
-    sub my_tmpl_pre_process {
+    sub template_pre_process {
         my ($self, $template) = @_;
 
         # Change the internal template parameters by reference
@@ -1272,25 +890,23 @@ using the C<param> method:
     }
 
 
-After the template output is generated, the C<template_post_process> hook is called.
-You can register a C<template_post_process> callback as follows:
+After the template output is generated, your application's
+C<< $self->template_post_process >> method is called.
+This method is passed a reference to the template object and a reference
+to the output generated by the template.  You can modify this output:
 
-    $self->add_callback('template_post_process', \&my_tmpl_post_process);
-
-Any callbacks that you register to this hook will be called after each
-template is processed, and will be passed both a reference to the
-template object and a reference to the output generated by the template.
-This allows you to modify the output of the template:
-
-    sub my_tmpl_post_process {
+    sub template_post_process {
         my ($self, $template, $output_ref) = @_;
 
         $$output_ref =~ s/foo/bar/;
     }
 
 
+When you call the C<output> method, any components embedded in the
+template are run.  See L<COMPONENT DISPATCH>, below.
 
-=head1 EMBEDDED COMPONENTS
+
+=head1 COMPONENT DISPATCH
 
 =head2 Introduction
 
@@ -1309,30 +925,26 @@ template and return the template's output.
 This output returned from the embedded run mode is inserted into the
 containing template.
 
-The syntax for embed components is specific to each type of template
-driver.
+The syntax for dispatching to embedded components is specific to each
+type of template driver.
 
 =head2 Syntax
 
 L<HTML::Template> syntax:
 
-    <TMPL_VAR NAME="CGIAPP_embed('some_run_mode')">
+    <TMPL_VAR NAME="CGIAPP_dispatch('some_run_mode')">
 
 L<HTML::Template::Expr> syntax:
 
-    <TMPL_VAR EXPR="CGIAPP_embed('some_run_mode')">
+    <TMPL_VAR EXPR="CGIAPP_dispatch('some_run_mode')">
 
-L<HTML::Template::Pluggable> syntax:
+L<Template::Toolkit> syntax:
 
-    <TMPL_VAR EXPR="cgiapp.embed('some_run_mode')">
-
-L<Template::Toolkit|Template> syntax:
-
-    [% CGIAPP.embed("some_run_mode") %]
+    [% CGIAPP.dispatch("some_run_mode") %]
 
 L<Petal> syntax:
 
-    <span tal:replace="structure CGIAPP/embed 'some_run_mode'">
+    <span tal:replace="structure CGIAPP/dispatch 'some_run_mode'">
         this text gets replaced by the output of some_run_mode
     </span>
 
@@ -1374,28 +986,24 @@ barewords.
 
 L<HTML::Template> syntax:
 
-    <TMPL_VAR NAME="CGIAPP_embed('some_run_mode', param1, 'literal string2')">
+    <TMPL_VAR NAME="CGIAPP_dispatch('some_run_mode', param1, 'literal string2')">
 
 I<Note that HTML::Template doesn't support this type of callback natively>
 I<and that this behaviour is emulated by the HTMLTemplate driver>
-I<see the docs to> L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate>
+I<see the docs to> L<CGI::Application::AnyTemplate::Driver::HTMLTemplate>
 I<for limitations to the emulation>.
 
 L<HTML::Template::Expr> syntax:
 
-    <TMPL_VAR EXPR="CGIAPP_embed('some_run_mode', param1, 'literal string2')">
+    <TMPL_VAR EXPR="CGIAPP_dispatch('some_run_mode', param1, 'literal string2')">
 
-L<HTML::Template::Pluggable> syntax:
+L<Template::Toolkit> syntax:
 
-    <TMPL_VAR EXPR="cgiapp.embed('some_run_mode', param1, 'literal string2')">
-
-L<Template::Toolkit|Template> syntax:
-
-    [% CGIAPP.embed("some_run_mode", param1, 'literal string2' ) %]
+    [% CGIAPP.dispatch("some_run_mode", param1, 'literal string2' ) %]
 
 L<Petal> syntax:
 
-    <span tal:replace="structure CGIAPP/embed 'some_run_mode' param1 'literal string2' ">
+    <span tal:replace="structure CGIAPP/dispatch 'some_run_mode' param1 'literal string2' ">
         this text gets replaced by the output of some_run_mode
     </span>
 
@@ -1403,53 +1011,6 @@ L<Petal> syntax:
 =cut
 
 
-=head1 NOTES FOR AUTHORS OF PLUGINS AND REUSABLE APPLICATIONS
-
-If you are writing a L<CGI::Application> plugin module, or you are
-writing a C<CGI::Application> program that will be distributed to other
-people (e.g. on CPAN), then it's important to take steps to prevent your
-application's use of L<CGI::Application::Plugin::AnyTemplate> from
-conflicting with other plugins or with your end users.
-
-When a plugin that uses L<CGI::Application::Plugin::AnyTemplate> calls:
-
-   $self->template->config(...)
-
-It overwrites any existing template configuration with the new settings.
-So if two plugins do that, they probably clobber each other.
-
-However, L<CGI::Application::Plugin::AnyTemplate> has the feature of
-named independent configs:
-
-   $self->template('your_module')->config(...)
-   $self->template('my_plugin')->config(...)
-
-These configs remain separate from each other.  However, you have to
-keep using these names throughout your module, even when you load and
-fill the template.  For instance:
-
-   sub my_runmode {
-       my $self = shift;
-       my $template = $self->template('my_plugin')->load;
-       $template->output;
-   }
-
-   sub your_runmode {
-       my $self = shift;
-       my %params;
-       $self->template('your_module')->fill(\%params);
-   }
-
-It's uglier and more verbose, but it also prevents plugins from
-stepping on each other's toes.
-
-L<CGI::Application> plugins that use
-L<CGI::Application::Plugin::AnyTemplate> should default to
-using their own package name for the AnyTemplate config name:
-
-   $self->template(__PACKAGE__)->config(...);
-   $self->template(__PACKAGE__)->fill(...);
-
 =head1 CHANGING THE NAME OF THE 'template' METHOD
 
 If you want to access the features of this module using a method other
@@ -1529,10 +1090,9 @@ be notified of progress on your bug as I make changes.
 =head1 SEE ALSO
 
     CGI::Application::Plugin::AnyTemplate::Base
-    CGI::Application::Plugin::AnyTemplate::ComponentHandler
+    CGI::Application::Plugin::AnyTemplate::Dispatcher
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
-    CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplatePluggable
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
     CGI::Application::Plugin::AnyTemplate::Driver::Petal
 
@@ -1540,10 +1100,6 @@ be notified of progress on your bug as I make changes.
 
     Template::Toolkit
     HTML::Template
-
-    HTML::Template::Pluggable
-    HTML::Template::Plugin::Dot
-
     Petal
 
     Exporter::Renaming
@@ -1560,4 +1116,4 @@ under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
