@@ -29,12 +29,11 @@ sub _new {
     $self->{'native_config'}    = delete $args{'native_config'} || {};
     $self->{'include_paths'}    = delete $args{'include_paths'} || [];
     $self->{'filename'}         = delete $args{'filename'};
-    $self->{'string_ref'}       = delete $args{'string_ref'};
     $self->{'callers_package'}  = delete $args{'callers_package'};
     $self->{'webapp'}           = delete $args{'webapp'};
 
-    $self->{'component_handler_class'} = delete $args{'component_handler_class'}
-                                || 'CGI::Application::Plugin::AnyTemplate::ComponentHandler';
+    $self->{'dispatcher_class'} = delete $args{'dispatcher_class'}
+                                || 'CGI::Application::Plugin::AnyTemplate::Dispatcher';
 
     bless $self, $class;
 
@@ -147,18 +146,13 @@ You can also supply names and values to the template at this stage:
 
     return $template->output('name' => 'value', 'name2' => 'value2');
 
-Before the template output is generated, the C<< template_pre_process >>
-hook is called.  Any callbacks that you register to this hook will be
-called before each template is processed.  Register a
-C<template_pre_process> callback as follows:
+Before the template output is generated, your application's
+C<< $self->template_pre_process >> method is called.
+This method is passed a reference to the C<$template> object.
 
-    $self->add_callback('template_pre_process', \&my_tmpl_pre_process);
+It can modify the parameters passed into the template by using the C<param> method:
 
-Pre-process callbacks will be passed a reference to the C<$template>
-object, and can can modify the parameters passed into the template by
-using the C<param> method:
-
-    sub my_tmpl_pre_process {
+    sub template_pre_process {
         my ($self, $template) = @_;
 
         # Change the internal template parameters by reference
@@ -174,27 +168,20 @@ using the C<param> method:
     }
 
 
-After the template output is generated, the C<template_post_process> hook is called.
-You can register a C<template_post_process> callback as follows:
+After the template output is generated, your application's
+C<< $self->template_pre_process >> method is called.
+This method is passed a reference to the template object and a reference
+to the output generated by the template.  You can modify this output:
 
-    $self->add_callback('template_post_process', \&my_tmpl_post_process);
-
-Any callbacks that you register to this hook will be called after each
-template is processed, and will be passed both a reference to the
-template object and a reference to the output generated by the template.
-This allows you to modify the output of the template:
-
-    sub my_tmpl_post_process {
+    sub template_post_process {
         my ($self, $template, $output_ref) = @_;
 
         $$output_ref =~ s/foo/bar/;
     }
 
 
-
-
 When you call the C<output> method, any components embedded in the
-template are run.  See C<EMBEDDED COMPONENTS>, below.
+template are run.  See C<COMPONENT DISPATCH>, below.
 
 =cut
 
@@ -212,18 +199,16 @@ sub output {
 
     $self->param(@_);
 
-    my $webapp = $self->{'webapp'};
-
-    if ($webapp and $webapp->can('call_hook')) {
-        $webapp->call_hook('template_pre_process', $self);
+    if ($self->{'webapp'} and UNIVERSAL::can($self->{'webapp'}, 'template_pre_process')) {
+        $self->{'webapp'}->template_pre_process($self);
     }
 
     my $output = $self->render_template;
 
-    if ($webapp and $webapp->can('call_hook')) {
+    if ($self->{'webapp'} and UNIVERSAL::can($self->{'webapp'}, 'template_post_process')) {
         my $output_param = $output;
         $output_param = \$output_param unless ref $output_param;
-        $webapp->call_hook('template_post_process', $output_param);
+        $self->{'webapp'}->template_post_process($output_param);
     }
     return $output;
 
@@ -231,7 +216,7 @@ sub output {
 
 =item filename
 
-If the template was loaded from a file, the C<filename> method returns the template filename.
+Get the template filename.
 
 =cut
 
@@ -240,17 +225,6 @@ sub filename {
     return $self->{'filename'};
 }
 
-=item string_ref
-
-If the template was loaded from a string, the C<string_ref> method returns a reference to the string.
-
-=cut
-
-sub string_ref {
-    my $self = shift;
-    return $self->{'string_ref'};
-}
-
 =item object
 
 Returns a reference to the underlying template driver, e.g. the
@@ -312,28 +286,28 @@ For instance, the user can specify
 
     $self->template->config(
         HTMLTemplate => {
-              embed_tag_name    => 'embed',
-              global_vars       => 1,
-              die_on_bad_params => 0,
-              cache             => 1
+              dispatch_tag_name     => 'dispatch',
+              global_vars           => 1,
+              die_on_bad_params     => 0,
+              cache                 => 1
         },
     );
 
 The parameters C<global_vars>, C<die_on_bad_params>, and C<cache> are all
 specific to L<HTML::Template>.  These are considered I<native> parameters.
 
-But C<embed_tag_name> configures the
-C<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate> subclass.  This
+But C<dispatch_tag_name> configures the
+C<CGI::Application::Plugin::AnyTemplate::HTMLTemplate> subclass.  This
 is considered a I<driver> parameter.
 
-Therefore C<'embed_tag_name'> should be included in the list of
+Therefore C<'dispatch_tag_name'> should be included in the list of
 params returned by C<driver_config_params>.
 
 Example C<driver_config_params>:
 
     sub driver_config_keys {
         'template_extension',
-        'embed_tag_name'
+        'dispatch_tag_name'
     }
 
 =cut
@@ -351,7 +325,7 @@ For instance:
     sub default_driver_config {
         {
             template_extension => '.foo',
-            embed_tag_name     => 'embed',
+            dispatch_tag_name  => 'dispatch',
         };
     }
 
@@ -369,7 +343,7 @@ of filling the template in C<< $self->filename >> with the values in C<< $self->
 via the appropriate template system, and returning the output as either
 a string or a reference to a string.
 
-It also must manage embedding nested components.
+It also must manage dispatch to nested components.
 
 =back
 
@@ -415,7 +389,7 @@ be notified of progress on your bug as I make changes.
 =head1 SEE ALSO
 
     CGI::Application::Plugin::AnyTemplate
-    CGI::Application::Plugin::AnyTemplate::ComponentHandler
+    CGI::Application::Plugin::AnyTemplate::Dispatcher
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
