@@ -3,7 +3,7 @@ package CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate;
 
 =head1 NAME
 
-CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate - HTML::Template driver to AnyTemplate
+CGI::Application::Plugin::AnyTemplate::HTMLTemplate - HTML::Template driver to AnyTemplate
 
 =head1 DESCRIPTION
 
@@ -15,25 +15,25 @@ All C<AnyTemplate> drivers are designed to be used the same way.  For
 general usage instructions, see the documentation of
 L<CGI::Application::Plugin::AnyTemplate>.
 
-=head1 EMBEDDED COMPONENT SYNTAX (HTML::Template)
+=head1 COMPONENT DISPATCH SYNTAX (HTML::Template)
 
 =head2 Syntax
 
-The L<HTML::Template> syntax for embedding components is:
+The L<HTML::Template> syntax for component dispatch is:
 
-    <TMPL_VAR NAME="cgiapp_embed('some_run_mode', param1, param2, 'literal string3')">
+    <TMPL_VAR NAME="cgiapp_dispatch('some_run_mode', param1, param2, 'literal string3')">
 
 I<(Support for parameter passing is limited.  See the note on paramters below.)>
 
 This can be overridden by the following configuration variables:
 
-    embed_tag_name       # default 'cgiapp_embed'
+    dispatch_tag_name       # default 'cgiapp_dispatch'
 
 For instance by setting the following value in your configuration file:
 
-    embed_tag_name       '***component***'
+    dispatch_tag_name       '***component***'
 
-Then the embedded component tag will look like:
+Then the component dispatch tag will look like:
 
     <TMPL_VAR NAME="***component***('some_run_mode')">
 
@@ -42,7 +42,7 @@ Then the embedded component tag will look like:
 Since L<HTML::Template> doesn't support parameter passing in the
 template, the C<HTMLTemplate> driver emulates this behaviour.
 
-The parameter list passed to the embed subroutine is parsed before
+The parameter list passed to the dispatch subroutine is parsed before
 the template is parsed.  Literal strings (strings enclosed in single or
 double quotes) are passed verbatim to the target run mode.  Params not
 enclosed in quotes are looked up in C<< $self->param >>; the resulting
@@ -66,11 +66,9 @@ driver instead.
 use strict;
 use Carp;
 
-use CGI::Application::Plugin::AnyTemplate::ComponentHandler;
+use CGI::Application::Plugin::AnyTemplate::Dispatcher;
 
-use CGI::Application::Plugin::AnyTemplate::Base;
-use vars qw(@ISA);
-@ISA = ('CGI::Application::Plugin::AnyTemplate::Base');
+use base 'CGI::Application::Plugin::AnyTemplate::Base';
 
 =head1 CONFIGURATION
 
@@ -79,10 +77,10 @@ accepts the following config parameters:
 
 =over 4
 
-=item embed_tag_name
+=item dispatch_tag_name
 
-The name of the tag used for embedding components.  Defaults to
-C<cgiapp_embed>.
+The name of the tag used for component dispatch.  Defaults to
+C<cgiapp_dispatch>.
 
 =item template_extension
 
@@ -93,8 +91,6 @@ the C<template_extension> is C<.html>.
 
 =item associate_query
 
-B<This feature is now deprecated and will be removed in a future release.>
-
 If this config parameter is true, then
 L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate> will
 copy all of the webapp's query params into the template using
@@ -104,7 +100,7 @@ L<HTML::Template>'s C<associate> mechanism:
         associate => $self->query,
     );
 
-By default C<associate_query> is false.
+By default C<associate_query> is true.
 
 If you provide an C<associate> config parameter of your own, that will
 disable the C<associate_query> functionality.
@@ -117,7 +113,7 @@ All other configuration parameters are passed on unchanged to L<HTML::Template>.
 
 sub driver_config_keys {
     qw/
-       embed_tag_name
+       dispatch_tag_name
        template_extension
        associate_query
     /;
@@ -126,8 +122,8 @@ sub driver_config_keys {
 sub default_driver_config {
     (
         template_extension => '.html',
-        embed_tag_name     => 'CGIAPP_embed',
-        associate_query    => 0,
+        dispatch_tag_name  => 'CGIAPP_dispatch',
+        associate_query    => 1,
     );
 }
 
@@ -161,7 +157,6 @@ C<CGI::Application::Plugin::AnyTemplate::Base> for details.
 #   $self->{'driver_config'}  # config info
 #   $self->{'include_paths'}  # the paths to search for the template file
 #   $self->filename           # the template file
-#   $self->string_ref         # ...or the template string
 #   $self->{'webapp'}->query  # for HTML::Template's 'associate' method,
 #                             # so that the query params are included
 #                             # in the template output
@@ -170,25 +165,15 @@ sub initialize {
 
     $self->_require_prerequisite_modules;
 
-    my $string_ref = $self->string_ref;
-    my $filename   = $self->filename;
-
-    $string_ref or $filename or croak "HTML::Template: file or string must be specified";
-
+    my $filename = $self->filename or croak "HTML::Template filename not specified";
     my $query    = $self->{'webapp'}->query or croak "HTML::Template webapp query not found";
 
     my %params = (
         %{ $self->{'native_config'} },
+        filename  => $filename,
         path      => $self->{'include_paths'},
     );
 
-    if ($filename) {
-        $params{'filename'} = $filename;
-    }
-    if ($string_ref) {
-        $params{'scalarref'} = $string_ref;
-    }
-
     if ($self->{'driver_config'}{'associate_query'}) {
         $params{'associate'} ||= $query;  # allow user to override associate with their own
     }
@@ -201,8 +186,8 @@ sub initialize {
 =item render_template
 
 Fills the C<HTML::Template> object with C<< $self->param >>
-replacing any magic C<*embed*> tags with the content generated by the
-appropriate runmodes.
+replacing any magic C<*dispatch*> tags with the content
+generated by the appropriate runmodes.
 
 Returns the output of the filled template as a string reference.
 
@@ -222,7 +207,7 @@ sub render_template {
 
     my $tag_match = '^'
                   . quotemeta(
-                       $driver_config->{'embed_tag_name'}
+                       $driver_config->{'dispatch_tag_name'}
                     )
                   . '\s*'
                   . '\((.*?)\)?'   # optional params
@@ -231,7 +216,7 @@ sub render_template {
 
     $tag_match    = qr/$tag_match/i;
 
-    my $component_handler = $self->{'component_handler_class'}->new(
+    my $dispatcher = $self->{'dispatcher_class'}->new(
         'webapp'              => $self->{'webapp'},
         'containing_template' => $self,
     );
@@ -239,7 +224,7 @@ sub render_template {
     # fill the template
     my $template = $self->{'driver'};
 
-    # fill the CGIAPP_embed(foo,...) tags
+    # fill the CGIAPP_dispatch(foo,...) tags
     foreach my $tag ($template->query) {
         # print STDERR "tag: $tag ($tag_match)\n";
         if ($tag =~ $tag_match) {
@@ -265,7 +250,7 @@ sub render_template {
             my $run_mode = shift @prepped_params;
             # print STDERR "rm: $run_mode (@prepped_params)\n";
 
-            $self->param($tag => ${ $component_handler->embed_direct($run_mode, @prepped_params) });
+            $self->param($tag => ${ $dispatcher->dispatch_direct($run_mode, @prepped_params) });
         }
     }
 
@@ -278,7 +263,7 @@ sub render_template {
 
     CGI::Application::Plugin::AnyTemplate
     CGI::Application::Plugin::AnyTemplate::Base
-    CGI::Application::Plugin::AnyTemplate::ComponentHandler
+    CGI::Application::Plugin::AnyTemplate::Dispatcher
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
     CGI::Application::Plugin::AnyTemplate::Driver::Petal
