@@ -3,7 +3,7 @@ package CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr;
 
 =head1 NAME
 
-CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr - HTML::Template::Expr driver to AnyTemplate
+CGI::Application::Plugin::AnyTemplate::HTMLTemplateExpr - HTML::Template::Expr driver to AnyTemplate
 
 =head1 DESCRIPTION
 
@@ -15,27 +15,27 @@ All C<AnyTemplate> drivers are designed to be used the same way.  For
 general usage instructions, see the documentation of
 L<CGI::Application::Plugin::AnyTemplate>.
 
-=head1 EMBEDDED COMPONENT SYNTAX (HTML::Template::Expr)
+=head1 COMPONENT DISPATCH SYNTAX (HTML::Template::Expr)
 
 =head2 Syntax
 
-The L<HTML::Template::Expr> syntax for embedding components is:
+The L<HTML::Template::Expr> syntax for component dispatch is:
 
-    <TMPL_VAR EXPR="CGIAPP_embed('some_run_mode', param1, param2, 'literal string3')">
+    <TMPL_VAR EXPR="CGIAPP_dispatch('some_run_mode', param1, param2, 'literal string3')">
 
 This can be overridden by the following configuration variables:
 
-    embed_tag_name       # default 'CGIAPP_embed'
+    dispatch_tag_name       # default 'CGIAPP_dispatch'
 
 For instance by setting the following value in your configuration file:
 
-    embed_tag_name       '__ACME_render'
+    dispatch_tag_name       '__ACME_render'
 
-Then the embedded component tag will look like:
+Then the component dispatch tag will look like:
 
     <TMPL_VAR EXPR="__ACME_render('some_run_mode')">
 
-The value of C<embed_tag_name> must consist of numbers, letters and
+The value of C<dispatch_tag_name> must consist of numbers, letters and
 underscores (C<_>), and must not begin with a number.
 
 =cut
@@ -43,11 +43,9 @@ underscores (C<_>), and must not begin with a number.
 use strict;
 use Carp;
 
-use CGI::Application::Plugin::AnyTemplate::ComponentHandler;
+use CGI::Application::Plugin::AnyTemplate::Dispatcher;
 
-use CGI::Application::Plugin::AnyTemplate::Base;
-use vars qw(@ISA);
-@ISA = ('CGI::Application::Plugin::AnyTemplate::Base');
+use base 'CGI::Application::Plugin::AnyTemplate::Base';
 
 =head1 CONFIGURATION
 
@@ -56,10 +54,10 @@ accepts the following config parameters:
 
 =over 4
 
-=item embed_tag_name
+=item dispatch_tag_name
 
-The name of the tag used for embedding components.  Defaults to
-C<CGIAPP_embed>.
+The name of the tag used for component dispatch.  Defaults to
+C<CGIAPP_dispatch>.
 
 =item template_extension
 
@@ -70,8 +68,6 @@ the C<template_extension> is C<.html>.
 
 =item associate_query
 
-B<This feature is now deprecated and will be removed in a future release.>
-
 If this config parameter is true, then
 L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr> will
 copy all of the webapp's query params into the template using
@@ -81,7 +77,7 @@ L<HTML::Template::Expr>'s C<associate> mechanism:
         associate => $self->query,
     );
 
-By default C<associate_query> is false.
+By default C<associate_query> is true.
 
 If you provide an C<associate> config parameter of your own, that will
 disable the C<associate_query> functionality.
@@ -94,7 +90,7 @@ All other configuration parameters are passed on unchanged to L<HTML::Template::
 
 sub driver_config_keys {
     qw/
-       embed_tag_name
+       dispatch_tag_name
        template_extension
        associate_query
     /;
@@ -103,8 +99,8 @@ sub driver_config_keys {
 sub default_driver_config {
     (
         template_extension => '.html',
-        embed_tag_name     => 'CGIAPP_embed',
-        associate_query    => 0,
+        dispatch_tag_name  => 'CGIAPP_dispatch',
+        associate_query    => 1,
     );
 }
 
@@ -146,33 +142,22 @@ sub initialize {
 
     $self->_require_prerequisite_modules;
 
-    my $string_ref = $self->string_ref;
-    my $filename   = $self->filename;
-
-    $string_ref or $filename or croak "HTML::Template file or string must be specified";
-
+    my $filename = $self->filename or croak "HTML::Template::Expr filename not specified";
     my $query    = $self->{'webapp'}->query or croak "HTML::Template::Expr webapp query not found";
 
-    my $component_handler = $self->{'component_handler_class'}->new(
+    my $dispatcher = $self->{'dispatcher_class'}->new(
         'webapp'              => $self->{'webapp'},
         'containing_template' => $self,
     );
 
     my %params = (
         %{ $self->{'native_config'} },
+        filename  => $filename,
         path      => $self->{'include_paths'},
         functions => {
-            $self->{'driver_config'}{'embed_tag_name'} => sub { $component_handler->embed(@_) },
+            $self->{'driver_config'}{'dispatch_tag_name'} => sub { $dispatcher->dispatch(@_) },
         }
     );
-
-    if ($filename) {
-        $params{'filename'} = $filename;
-    }
-    if ($string_ref) {
-        $params{'scalarref'} = $string_ref;
-    }
-
     if ($self->{'driver_config'}{'associate_query'}) {
         $params{'associate'} ||= $query;  # allow user to override associate with their own
     }
@@ -210,7 +195,7 @@ sub render_template {
 
     CGI::Application::Plugin::AnyTemplate
     CGI::Application::Plugin::AnyTemplate::Base
-    CGI::Application::Plugin::AnyTemplate::ComponentHandler
+    CGI::Application::Plugin::AnyTemplate::Dispatcher
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
     CGI::Application::Plugin::AnyTemplate::Driver::Petal
