@@ -3,7 +3,7 @@ package CGI::Application::Plugin::AnyTemplate::Driver::Petal;
 
 =head1 NAME
 
-CGI::Application::Plugin::AnyTemplate::Driver::Petal - Petal plugin to AnyTemplate
+CGI::Application::Plugin::AnyTemplate::Petal - Petal plugin to AnyTemplate
 
 =head1 DESCRIPTION
 
@@ -15,32 +15,32 @@ All C<AnyTemplate> drivers are designed to be used the same way.  For
 general usage instructions, see the documentation of
 L<CGI::Application::Plugin::AnyTemplate>.
 
-=head1 EMBEDDED COMPONENT SYNTAX (Petal)
+=head1 COMPONENT DISPATCH SYNTAX (Petal)
 
-B<Note that for embedding component to work properly in Petal, you need to enclose>
+B<Note that for component dispatch under Petal to work properly, you need to enclose>
 B<the contents of the included file in tags, such as C<< <span> >> tags.>
 
     <span>
     var: <span petal:replace="var"></span>
     </span>
 
-The C<Petal> syntax for embedding components is:
+The C<Petal> syntax for component dispatch is:
 
-    <span tal:replace="structure CGIAPP/embed 'some_run_mode' some_param1 some_param2 'some literal string 3'">
+    <span tal:replace="structure CGIAPP/dispatch 'some_run_mode' some_param1 some_param2 'some literal string 3'">
         this text gets replaced by the output of some_run_mode
     </span>
 
 This can be overridden by the following configuration variables:
 
-    embed_tag_name       # default 'CGIAPP'
+    dispatch_tag_name       # default 'CGIAPP'
 
 For instance by setting the following values in your configuration file:
 
-    embed_tag_name       'MYAPP'
+    dispatch_tag_name       'MYAPP'
 
-Then the embedded component tag will look like:
+Then the component dispatch tag will look like:
 
-    <span tal:replace="structure MYAPP/embed 'some_run_mode'">
+    <span tal:replace="structure MYAPP/dispatch 'some_run_mode'">
         this text gets replaced by the output of some_run_mode
     </span>
 
@@ -53,11 +53,9 @@ must be complete XML documents.
 use strict;
 use Carp;
 
-use CGI::Application::Plugin::AnyTemplate::ComponentHandler;
+use CGI::Application::Plugin::AnyTemplate::Dispatcher;
 
-use CGI::Application::Plugin::AnyTemplate::Base;
-use vars qw(@ISA);
-@ISA = ('CGI::Application::Plugin::AnyTemplate::Base');
+use base 'CGI::Application::Plugin::AnyTemplate::Base';
 
 =head1 CONFIGURATION
 
@@ -66,9 +64,9 @@ accepts the following config parameters:
 
 =over 4
 
-=item embed_tag_name
+=item dispatch_tag_name
 
-The name of the tag used for embedding components.  Defaults to
+The name of the tag used for component dispatch.  Defaults to
 C<CGIAPP>.
 
 =item template_extension
@@ -80,8 +78,6 @@ the C<template_extension> is C<.xhtml>.
 
 =item emulate_associate_query
 
-B<This feature is now deprecated and will be removed in a future release.>
-
 If this config parameter is true, then L<CGI::Application::Plugin::AnyTemplate::Driver::Petal>
 will copy all of the webapp's query params into the template.
 
@@ -92,7 +88,7 @@ C<associate> feature with the webapp's query object:
         associate => $self->query,
     );
 
-By default C<emulate_associate_query> is false.
+By default C<emulate_associate_query> is true.
 
 =back
 
@@ -102,7 +98,7 @@ All other configuration parameters are passed on unchanged to L<Petal>.
 
 sub driver_config_keys {
     qw/
-       embed_tag_name
+       dispatch_tag_name
        template_extension
        emulate_associate_query
     /;
@@ -111,8 +107,8 @@ sub driver_config_keys {
 sub default_driver_config {
     (
         template_extension      => '.xhtml',
-        embed_tag_name          => 'CGIAPP',
-        emulate_associate_query => 0,
+        dispatch_tag_name       => 'CGIAPP',
+        emulate_associate_query => 1,
     );
 }
 
@@ -150,28 +146,13 @@ sub initialize {
 
     $self->_require_prerequisite_modules;
 
-    # TODO: check out how Petal caching works
+    # TODO: check out how Petal caching work
 
     my %config = %{ $self->{'native_config'}};
     $config{'base_dir'} = $self->{'include_paths'};
+    $config{'file'}     = $self->filename;
 
-    my $filename   = $self->filename;
-    my $string_ref = $self->string_ref;
-
-
-    my $driver;
-    if ($filename) {
-        $config{'file'} = $filename;
-        $driver         = Petal->new(%config);
-    }
-    elsif ($string_ref) {
-        croak "Petal: creating templates from strings is not supported in Petal";
-    }
-    else {
-        croak "Petal: either file or string must be specified";
-    }
-
-
+    my $driver = Petal->new(%config);
 
     $self->{'driver'} = $driver;
 }
@@ -184,8 +165,8 @@ If the param C<emulate_associate_query> is true, then set params for each of
 $self->{'webapp'}->query, mimicking L<HTML::Template>'s associate
 mechanism.
 
-Also set up a L<CGI::Application::Plugin::AnyTemplate::ComponentHandler>
-object so that the C<CGIAPP.embed> callback will work.
+Also set up a L<CGI::Application::Plugin::AnyTemplate::Dispatcher>
+object so that the C<CGIAPP.dispatch> callback will work.
 
 Returns the output of the filled template as a string reference.
 
@@ -212,13 +193,13 @@ sub render_template {
         }
     }
 
-    my $component_handler = $self->{'component_handler_class'}->new(
+    my $dispatcher = $self->{'dispatcher_class'}->new(
         'webapp'              => $self->{'webapp'},
         'containing_template' => $self,
     );
 
     my $params = $self->get_param_hash;
-    $params->{$driver_config->{'embed_tag_name'}} = $component_handler;
+    $params->{$driver_config->{'dispatch_tag_name'}} = $dispatcher;
 
     my $output = $template->process($params) || croak $template->error;
     return \$output;
@@ -228,7 +209,7 @@ sub render_template {
 
     CGI::Application::Plugin::AnyTemplate
     CGI::Application::Plugin::AnyTemplate::Base
-    CGI::Application::Plugin::AnyTemplate::ComponentHandler
+    CGI::Application::Plugin::AnyTemplate::Dispatcher
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
     CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
