@@ -9,47 +9,47 @@ CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit - Template::Toolk
 
 This is a driver for L<CGI::Application::Plugin::AnyTemplate>, which
 provides the implementation details specific to rendering templates via
-the L<Template::Toolkit|Template> templating system.
+the L<Template::Toolkit> templating system.
 
 All C<AnyTemplate> drivers are designed to be used the same way.  For
 general usage instructions, see the documentation of
 L<CGI::Application::Plugin::AnyTemplate>.
 
-=head1 EMBEDDED COMPONENT SYNTAX (Template::Toolkit)
+=head1 COMPONENT DISPATCH SYNTAX (Template::Toolkit)
 
-The L<Template::Toolkit|Template> syntax for embedding components is:
+The L<Template::Toolkit> syntax for component dispatch is:
 
-    [% CGIAPP.embed("some_run_mode", param1, param2, 'literal string3') %]
+    [% CGIAPP.dispatch("some_run_mode", param1, param2, 'literal string3') %]
 
 This can be overridden by the following configuration variables:
 
-    embed_tag_name       # default 'CGIAPP'
+    dispatch_tag_name       # default 'CGIAPP'
 
 For instance by setting the following values in your configuration file:
 
-    embed_tag_name       'MYAPP'
+    dispatch_tag_name       'MYAPP'
 
-Then the embedded component tag will look like:
+Then the component dispatch tag will look like:
 
-    [% MYAPP.embed("some_run_mode") %]
+    [% MYAPP.dispatch("some_run_mode") %]
 
 
 =head1 TT OBJECT CACHING (singleton support)
 
 =head2 Introduction
 
-In a persistent environment, rather than creating a L<Template::Toolkit|Template>
+In a persistent environment, rather than creating a C<Template::Toolkit>
 object each time you fill a template, it is much more efficient to load
-a single L<Template::Toolkit|Template> object and use this object to render all
+a single C<Template::Toolkit> object and use this object to render all
 of your templates.
 
 However, in a persistent environment, you may have several different
 applications running, and they all might need to set different
-L<Template::Toolkit|Template> options (such as C<POST_CHOMP>, etc.).
+C<Template::Toolkit> options (such as C<POST_CHOMP>, etc.).
 
 By default, when the C<TemplateToolkit> driver creates a
-L<Template::Toolkit|Template> object, it caches it.  From that point on, whenever
-the same application needs a L<Template::Toolkit|Template> object, the driver
+C<Template::Toolkit> object, it caches it.  From that point on, whenever
+the same application needs a C<Template::Toolkit> object, the driver
 uses the cached object rather than creating a new one.
 
 =head2 Multiple Applications in a Shared Persistent Environment
@@ -93,7 +93,7 @@ C<< $self->template->config >>.
 
 =head2 Disabling TT Object Caching
 
-You can disable L<Template::Toolkit|Template> object caching entirely by
+You can disable C<Template::Toolkit> object caching entirely by
 providing a false value to the C<object_caching> driver config
 parameter:
 
@@ -116,11 +116,9 @@ different C<include_paths>.
 use strict;
 use Carp;
 
-use CGI::Application::Plugin::AnyTemplate::ComponentHandler;
+use CGI::Application::Plugin::AnyTemplate::Dispatcher;
 
-use CGI::Application::Plugin::AnyTemplate::Base;
-use vars qw(@ISA);
-@ISA = ('CGI::Application::Plugin::AnyTemplate::Base');
+use base 'CGI::Application::Plugin::AnyTemplate::Base';
 
 =head1 CONFIGURATION
 
@@ -129,9 +127,9 @@ accepts the following config parameters:
 
 =over 4
 
-=item embed_tag_name
+=item dispatch_tag_name
 
-The name of the tag used for embedding components.  Defaults to
+The name of the tag used for component dispatch.  Defaults to
 C<CGIAPP>.
 
 =item template_extension
@@ -143,8 +141,6 @@ the C<template_extension> is C<.xhtml>.
 
 =item emulate_associate_query
 
-B<This feature is now deprecated and will be removed in a future release.>
-
 If this config parameter is true, then L<CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit>
 will copy all of the webapp's query params into the template.
 
@@ -155,15 +151,15 @@ C<associate> feature with the webapp's query object:
         associate => $self->query,
     );
 
-By default C<emulate_associate_query> is false.
+By default C<emulate_associate_query> is true.
 
 =item object_caching
 
-Whether or not to cache the L<Template::Toolkit|Template> object in a persistent environment
+Whether or not to cache the C<Template::Toolkit> object in a persistent environment
 
 By default, C<object_caching> is enabled.
 
-See L<"TT OBJECT CACHING (singleton support)">, above.
+See L<TT OBJECT CACHING (singleton support)>, above.
 
 =item storage_class
 
@@ -172,12 +168,12 @@ What class to use as the storage key when object caching is enabled.
 By default, C<storage_class> defaults to the package containing the
 subroutine that called C<< $self->template->config >>.
 
-See L<"TT OBJECT CACHING (singleton support)">, above.
+See L<TT OBJECT CACHING (singleton support)>, above.
 
 
 =back
 
-All other configuration parameters are passed on unchanged to L<Template::Toolkit|Template>.
+All other configuration parameters are passed on unchanged to L<Template::Toolkit>.
 
 =cut
 
@@ -186,7 +182,7 @@ sub driver_config_keys {
        storage_class
        object_caching
        cache_storage_keys
-       embed_tag_name
+       dispatch_tag_name
        template_extension
        emulate_associate_query
     /;
@@ -196,8 +192,8 @@ sub default_driver_config {
     (
         object_caching          => 1,
         template_extension      => '.tmpl',
-        embed_tag_name          => 'CGIAPP',
-        emulate_associate_query => 0,
+        dispatch_tag_name       => 'CGIAPP',
+        emulate_associate_query => 1,
     );
 }
 
@@ -263,14 +259,14 @@ sub initialize {
 
 =item render_template
 
-Fills the L<Template::Toolkit|Template> object with C<< $self->param >>
+Fills the L<Template::Toolkit> object with C<< $self->param >>
 
 If the param C<emulate_associate_query> is true, then set params for
 each of $self->{'webapp'}->query, mimicking L<HTML::Template>'s
 associate mechanism.
 
-Also set up a L<CGI::Application::Plugin::AnyTemplate::ComponentHandler>
-object so that the C<CGIAPP.embed> callback will work.
+Also set up a L<CGI::Application::Plugin::AnyTemplate::Dispatcher>
+object so that the C<CGIAPP.dispatch> callback will work.
 
 Returns the output of the filled template as a string reference.
 
@@ -300,20 +296,17 @@ sub render_template {
         }
     }
 
-    my $component_handler = $self->{'component_handler_class'}->new(
+    my $dispatcher = $self->{'dispatcher_class'}->new(
         'webapp'              => $self->{'webapp'},
         'containing_template' => $self,
     );
 
     my $params = $self->get_param_hash;
-    $params->{$driver_config->{'embed_tag_name'}} = $component_handler;
+    $params->{$driver_config->{'dispatch_tag_name'}} = $dispatcher;
 
-    my $filename   = $self->filename;
-    my $string_ref = $self->string_ref;
+    my $filename = $self->filename;
 
-    $string_ref or $filename or croak "TemplateToolkit: file or string must be specified";
-
-    $template->process(($string_ref || $filename), $params, \$output) || croak $template->error;
+    $template->process($self->filename, $params, \$output) || croak $template->error;
     return \$output;
 
 }
@@ -322,7 +315,7 @@ sub render_template {
 
     CGI::Application::Plugin::AnyTemplate
     CGI::Application::Plugin::AnyTemplate::Base
-    CGI::Application::Plugin::AnyTemplate::ComponentHandler
+    CGI::Application::Plugin::AnyTemplate::Dispatcher
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
     CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
     CGI::Application::Plugin::AnyTemplate::Driver::Petal
